/*************************************************************************
       TEXTURE TILER INCLUDE FILE FOR PERSISTENCE OF VISION 3.x
**************************************************************************

Created by Chris Colefax, March 1997
Updated 19 July 1997: added support for TileTexture and TileSeam
Updated 18 July 1998: updated for POV-Ray 3.1

OVERVIEW: Will take any POVRay pigment or texture and create a
seamlessly tilable image for use as web-page backgrounds, texture
maps, etc.

USAGE: To use this file with a pigment, declare your pigment as
TilePigment, eg:

  #declare TilePigment = pigment {wrinkles color_map {
     [0 rgb <1, 1, 0>] [1 rgb <1, 0, 0>]}
     turbulence 1 octaves 1 scale .2}

and then include this file.  No other commands are necessary.
To use this file with a complete texture, declare the texture
as TileTexture, eg:

  #include "colors.inc" #include "woods.inc"
  #declare TileTexture = texture {T_Wood32 scale 4 rotate <80, 0, 10>}

and then include this file.  You should also add any desired
light_sources.  For the best results the light_source(s) should
usually be very far away, so that the light rays are almost parallel, eg:

  light_source {-z * 100000 rgb <1, 1, 1>}

but you may wish to use a closer, differently angled light source to
obtain different effects (especially when using normals and finishes).

You can use the TileSeam to set the size of the seam in the centre
of the image, ranging from 0 (no seam) to 1 (gradual change from one
corner of the image to the other).

By default a one unit square of the texture (or pigment) is tiled
(from <0, 0, 0> to <1, 1, 0>).  You can optionally declare the size
of the tiled texture (in POV units), eg. #declare TileSize = <3, 6, 0>
will use a section of the texture 3 units wide by 6 units high (the z
value is ignored).  This should then be rendered with a suitable aspect
ratio, eg. width 30 and height 60.  You can scale, translate, and
rotate the TilePigment or TileTexture definition to tile different
sections of the texture.

*************************************************************************/

// CHECK VARIABLES AND ASSIGN DEFAULTS
// ***********************************
   #declare _TX_tempver = version; #version 3.0;
   #ifndef (TileSize) #declare _TX_size = <1, 1, 1>;
      #else #declare _TX_size = TileSize * <1, 1, 1>; #end
   #ifndef (TileSeam) #declare TileSeam = 1; #end
   camera {location <.5, .5, -1> look_at <.5, .5, 0> orthographic up y right x}

// CREATE TILED PIGMENT
// ********************
   #ifdef (TilePigment)
      #declare _TX_xpigment = pigment {gradient x pigment_map {
         [.5 - (TileSeam / 2) TilePigment scale <1 / _TX_size.x, 1, 1>]
         [.5 + (TileSeam / 2) TilePigment scale <1 / _TX_size.x, 1, 1> translate x]}}
      plane {-z, 0 pigment {gradient y pigment_map {
         [.5 - (TileSeam / 2) _TX_xpigment scale <1, 1 / _TX_size.y, 1>]
         [.5 + (TileSeam / 2) _TX_xpigment scale <1, 1 / _TX_size.y, 1> translate y]}}
         finish {ambient 1}}

// CREATE TILED TEXTURE
// ********************
   #else #ifdef (TileTexture)
      #declare _TX_xtexture = texture {gradient x texture_map {
         [.5 - (TileSeam / 2) TileTexture scale <1 / _TX_size.x, 1, 1>]
         [.5 + (TileSeam / 2) TileTexture scale <1 / _TX_size.x, 1, 1> translate x]}}
      plane {-z, 0 texture {gradient y texture_map {
         [.5 - (TileSeam / 2) _TX_xtexture scale <1, 1 / _TX_size.y, 1>]
         [.5 + (TileSeam / 2) _TX_xtexture scale <1, 1 / _TX_size.y, 1> translate y]}}}

   #else #warning "You must specify a TilePigment or TileTexture!\r\n"
   #end #end  #version _TX_tempver;
